@@ -1,13 +1,16 @@
 import argparse
+import string
 import sys
 
 from pokesummary import __version__, displaying, parsing
 
 
-def prepare_args():
+def prepare_args(args=None):
     """
     Use argparse to create the command-line interface.
 
+    :param args: a list of arguments passed to the program.
+    If no value is given, use the sys.argv[1:] arguments.
     :return: the namespace of program arguments
     """
     parser = argparse.ArgumentParser(
@@ -33,13 +36,12 @@ def prepare_args():
         action="version",
         version=f"pokesummary {__version__}",
     )
-    return parser.parse_args()
+    return parser.parse_args(args)
 
 
 def print_examples():
     """
-    Print example uses of the program,
-    along with commentary.
+    Print example uses of the program, along with commentary.
     """
     examples = """The simplest example is passing a Pokémon as an argument.
 Here, we want to display Bulbasaur's summary,
@@ -75,27 +77,32 @@ we can use the following to display each of their summaries.
 
 def safe_print(dictionary, pokemon):
     """
-    Try to print a summary of the Pokémon specified by string ``pokemon``.
-    If ``pokemon`` is not a key in the dictionary, return gracefully.
+    Try to print a summary of a Pokémon.
 
-    :param dictionary: the dict of Pokémon/Pokémon info pairs
-    :param pokemon: the key to access
+    If the given dictionary lacks the given Pokémon name as one of its keys,
+    handle it gracefully.
+
+    :param dictionary: the dict of Pokémon name/Pokémon info pairs
+    :param pokemon: the Pokémon name to look up
     """
     try:
         pokemon_stats = dictionary[pokemon]
     except KeyError:
         print(f"Invalid Pokémon {pokemon}\n")
         return
+
     displaying.display_summary(pokemon, pokemon_stats)
 
 
-def main():
+def run_program(pokemon, interactive, show_examples):
     """
-    Driver code.
-    """
-    args = prepare_args()
+    Run the program.
 
-    if args.show_examples:
+    :param pokemon: a list of Pokémon names to look up
+    :param interactive: if the program should read from standard input
+    :param show_examples: if the program should print example uses
+    """
+    if show_examples:
         print_examples()
         return
 
@@ -109,13 +116,21 @@ def main():
         "pokemon_name"
     )
 
-    input_pokemon = sys.stdin if args.interactive else args.pokemon
+    input_pokemon = sys.stdin if interactive else pokemon
     for pokemon in input_pokemon:
         safe_print(
             data_dictionary,
-            pokemon.rstrip().title()
+            string.capwords(pokemon)
         )
 
 
+def main():
+    """
+    Driver code.
+    """
+    cli_args = prepare_args()
+    run_program(**vars(cli_args))
+
+
 if __name__ == "__main__":
     main()
